@@ -32,6 +32,7 @@ class ScpiTransportBase(IO):
 
     def write(self, s: AnyStr) -> int:
         n = self.io.write(s)
+        self.io.flush()
         self.logger.debug(f'write: block with size of {n} bytes')
         return n
 
@@ -40,10 +41,11 @@ class ScpiTransportBase(IO):
         self.logger.debug(f'read line {str(data)[1:]}')
         return data.decode(self.encoding).rstrip(self.newline)
 
-    def writeline(self, line: str) -> Optional[int]:
+    def writeline(self, line: str) -> None:
         data = (line + self.newline).encode(self.encoding)
         self.logger.debug(f'write line {str(data)[1:]}')
-        return self.io.writelines([data])
+        self.io.writelines([data])
+        self.io.flush()
 
     def readlines(self, hint: int = ...) -> List[AnyStr]:
         raise UnsupportedOperation
